# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelResponse(Model):
    """AnalyticsModelResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: int
    :param name: Required.
    :type name: str
    :param version: Required.
    :type version: str
    :param properties:
    :type properties: list[~smartdiagnostics_sdk.models.PropertyChild]
    :param corporation:
    :type corporation: ~smartdiagnostics_sdk.models.CorporationChild
    :param location:
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param group_type: Possible values include: 'Invalid', 'Group', 'Asset',
     'MonitoringPoint', 'IndicatorGroup'
    :type group_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'version': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'int'},
        'name': {'key': 'Name', 'type': 'str'},
        'version': {'key': 'Version', 'type': 'str'},
        'properties': {'key': 'Properties', 'type': '[PropertyChild]'},
        'corporation': {'key': 'Corporation', 'type': 'CorporationChild'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'group_type': {'key': 'GroupType', 'type': 'str'},
    }

    def __init__(self, *, id: int, name: str, version: str, properties=None, corporation=None, location=None, group_type=None, **kwargs) -> None:
        super(AnalyticsModelResponse, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.version = version
        self.properties = properties
        self.corporation = corporation
        self.location = location
        self.group_type = group_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PagedResultsModelDashboardResponse(Model):
    """PagedResultsModelDashboardResponse.

    :param result:
    :type result: list[~smartdiagnostics_sdk.models.DashboardResponse]
    :param total:
    :type total: int
    :param total_pages:
    :type total_pages: int
    """

    _attribute_map = {
        'result': {'key': 'Result', 'type': '[DashboardResponse]'},
        'total': {'key': 'Total', 'type': 'int'},
        'total_pages': {'key': 'TotalPages', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(PagedResultsModelDashboardResponse, self).__init__(**kwargs)
        self.result = kwargs.get('result', None)
        self.total = kwargs.get('total', None)
        self.total_pages = kwargs.get('total_pages', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CustomMarkerChild(Model):
    """CustomMarkerChild.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name:
    :type name: str
    :param show_harmonics: Required.
    :type show_harmonics: bool
    :param show_side_bands: Required.
    :type show_side_bands: bool
    :param show_peaks: Required.
    :type show_peaks: bool
    """

    _validation = {
        'id': {'required': True},
        'name': {'max_length': 5},
        'show_harmonics': {'required': True},
        'show_side_bands': {'required': True},
        'show_peaks': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'show_harmonics': {'key': 'ShowHarmonics', 'type': 'bool'},
        'show_side_bands': {'key': 'ShowSideBands', 'type': 'bool'},
        'show_peaks': {'key': 'ShowPeaks', 'type': 'bool'},
    }

    def __init__(self, *, id: str, show_harmonics: bool, show_side_bands: bool, show_peaks: bool, name: str=None, **kwargs) -> None:
        super(CustomMarkerChild, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.show_harmonics = show_harmonics
        self.show_side_bands = show_side_bands
        self.show_peaks = show_peaks



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorResponse(Model):
    """IndicatorResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param system_sort_order:
    :type system_sort_order: int
    :param indicator_type:
    :type indicator_type: str
    :param display_units:
    :type display_units: str
    :param base_units:
    :type base_units: str
    :param has_spectrum:
    :type has_spectrum: bool
    :param hierarchy:
    :type hierarchy: list[~smartdiagnostics_sdk.models.HierarchyChild]
    :param alarm_definition:
    :type alarm_definition: ~smartdiagnostics_sdk.models.AlarmDefinitionChild
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'system_sort_order': {'key': 'SystemSortOrder', 'type': 'int'},
        'indicator_type': {'key': 'IndicatorType', 'type': 'str'},
        'display_units': {'key': 'DisplayUnits', 'type': 'str'},
        'base_units': {'key': 'BaseUnits', 'type': 'str'},
        'has_spectrum': {'key': 'HasSpectrum', 'type': 'bool'},
        'hierarchy': {'key': 'Hierarchy', 'type': '[HierarchyChild]'},
        'alarm_definition': {'key': 'AlarmDefinition', 'type': 'AlarmDefinitionChild'},
    }

    def __init__(self, **kwargs):
        super(IndicatorResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.system_sort_order = kwargs.get('system_sort_order', None)
        self.indicator_type = kwargs.get('indicator_type', None)
        self.display_units = kwargs.get('display_units', None)
        self.base_units = kwargs.get('base_units', None)
        self.has_spectrum = kwargs.get('has_spectrum', None)
        self.hierarchy = kwargs.get('hierarchy', None)
        self.alarm_definition = kwargs.get('alarm_definition', None)
